pub enum ErrorSubpage {
Secret,
Session,
}Expand description
The possible error subpages.
Variants
Secret
The page to present when there was an error with the secret API.
Session
The page to present when there was an error when initializing a session.
Implementations